@@ -1,7 +1,10 @@
 /*
- * $Id: alloc.h,v 1.6 2004/07/09 09:43:58 jklein Exp $
+ * $Id: alloc.h,v 1.7 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: alloc.h,v $
+ * Revision 1.7  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
  * Revision 1.6  2004/07/09 09:43:58  jklein
  * few small changes.
  *
@@ -25,31 +28,39 @@
    Ȥ˼٤ưϰʲΤɤ餫Ǥȹͤ롣</p>
 
    <ul>
-   <li>ץλ</li>
-   <li>Ƽ</li>
+     <li>ץλ</li>
+     <li>Ƽ</li>
    </ul>
 
    <p>⤷ʤΥץबԤˤȤΤʤСⵤˤ
    s_mallocƤӽФƤɤγݤ˼ԤȤϼưŪexit()
    Ƥ֡ԤˤʤСֲǤץϥɥ
-   ؿʰʲꥨ顼ϥɥˤs_merror_handler˥åȤɬפ
+   ؿʰʲꥨ顼ϥɥˤs_merror_handler()˥åȤɬפ
    롣ꥨ顼ϥɥ餬ԤʤʤФʤʤȤϰʲ̤</p>
 
    <ol>
-   <li></li>
-   <li>true򡢽ʤfalse֤</li>
+     <li></li>
+     <li>true򡢽ʤfalse֤</li>
    </ol>
 
    <p>⤷⡢褺false֤ȥץ¸³ԲǽȤơϤ
-   exit()ƤФޤtrue֤ХκƼԤʤޤ</p>
+   exit()ƤФ뤬true֤ХκƼԤʤȤ
+   ꥨ顼ϥɥ餬餫Υtrue֤Ƥ⡢ޤ
+   ݤ꤬­ʤȤ奨⤢롣Τ褦
+   ȤϷ֤ߤ꤬ݤǤޤǡ˥ꥨ顼ϥɥ
+   Ƥ³롣</p>
 
-   <p>ʤs_reallocn()s_freen()ϰˡز٤ꥵ٤򤦤
-   Ȥޤϥλ̤ƻ뤹뤿Scale饤֥⤫
-   ѤƤꡢ饤Ȥ˶ΤǤϤޤʥδƻ
-   Scale饤֥ꥳѥMEMORY_DEBUG򥻥åȤɬפޤˡ
-   ǽȤƤѤʤΤǡs_free()s_freen()ΤɤѤƤ⹽
-   󤬡ز褦ȤΥΤäƤ٤٤Ȥݥꥷ
-   ΰ٤s_freen(), s_reallocnѤ뤳Ȥ򤪿ᤷޤ</p>
+   <p>Scale󶡤ɸˤ̵ؿġҤȤĤϡs_realocn()
+   s_freen()ȤäǸ`n'դؿ⤦ҤȤĤs_creallocn()
+   s_cfreen()Ȥäǽ`c'դؿԤϡɽεǽȤƤ
+   `n'դʤΤƱScaleΥѥMEMORY_DEBUG
+   ȥγݡϿ褦ˤʤ롣ˤꡢ
+   ˺ʥ꡼ˤ򸫤Ĥ뤳ȤǽˤʤΤǡScale饤֥
+   ǤϾ`n'դƤ֡Ԥϡ¸εǽɲäƥ򥯥ꥢ
+   롣s_creallocn()ϳĥΰ`Τ'򥯥ꥢȤ
+   ꤬ݻǡϾäʤs_cfreen()ϥ򥯥ꥢƤ
+   Τǡѥɤ䵡̩Ȥǡפ
+   ळȤɤ</p>
 */
 
 #ifndef _SCALE_ALLOC_H_
@@ -66,17 +77,39 @@ typedef sboolean (*merror_handler)();
 
 
 /** ꡦ顼ϥɥ򥻥åȤ롣 */
-void			s_merror_handler(merror_handler *);
-spointer		s_malloc(size_t);
-spointer		s_calloc(size_t, size_t);
-spointer		s_realloc(spointer, size_t);
+void			s_merror_handler(merror_handler);
 
-/** Υꥵꤷơoldn˥ĥ */
+/** ݤ */
+spointer		s_malloc(size_t);
+
+/** ݤΤ0ǽ롣 */
+spointer		s_calloc(size_t, size_t);
+
+/** ĥ롣 */
+spointer		s_realloc(spointer p, size_t n);
+
+/** Υꥵꤷơoldn˥ĥ롣 */
 spointer		s_reallocn(spointer p, size_t oldn, size_t newn);
-void			s_free(spointer);
+
+/** ưs_reallocnƱ˳ݤ0ǽ롣
+	oldn >= newnǤȤs_reallocnȤޤäƱǤ롣*/
+spointer		s_creallocn(spointer p, size_t oldn, size_t newn);
+
+/** 롣 */
+void			s_free(spointer p);
 
 /** ꥵꤷƲ */
-void			s_freen(spointer, size_t);
+void			s_freen(spointer p, size_t n);
 
+/** s_freen()ƱpΤ0ǽ롣 */
+void			s_cfreen(spointer p, size_t n);
+
+/** Scale饤֥ΥѥMEMORY_DEBUGƤС
+	߳ݤƤ礭֤
+	scale/alloc.hƤϢΥϢؿ
+	̤ƵϿΤǡľmallocreallocѤϵϿʤ
+
+	ѥMEMORY_DEBUGƤʤäȤϾ0֤ */
+size_t			get_total_memory(void);
 
 #endif /* _SCALE_ALLOC_H_ */
