@@ -1,7 +1,10 @@
 /*
- * $Id: buffer.h,v 1.6 2004/06/28 09:51:09 jklein Exp $
+ * $Id: buffer.h,v 1.7 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: buffer.h,v $
+ * Revision 1.7  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
  * Revision 1.6  2004/06/28 09:51:09  jklein
  * interface was changed in scale/iterator.h
  *
@@ -54,7 +57,10 @@ struct _sc_buffer {
 };
 
 
-sbuffer_t *	s_buffer_alloc(size_t n);
+#define s_buffer_charat(sbuf, index) ((sbuf)->string[index])
+
+sbuffer_t *	s_buffer_alloc(void);
+sbuffer_t *	s_buffer_allocn(size_t n);
 sbuffer_t *	s_buffer_alloc_str(const char *src);
 void		s_buffer_free(sbuffer_t *sb);
 void		s_buffer_clear(sbuffer_t *sb);
