@@ -1,7 +1,10 @@
 /*
- * $Id: graph.h,v 1.1 2004/06/24 15:16:50 jklein Exp $
+ * $Id: graph.h,v 1.2 2004/07/09 09:43:58 jklein Exp $
  * $Author: jklein $
  * $Log: graph.h,v $
+ * Revision 1.2  2004/07/09 09:43:58  jklein
+ * few small changes.
+ *
  * Revision 1.1  2004/06/24 15:16:50  jklein
  * sxarray_t was added for abstruction of collection structure.
  *
@@ -43,6 +46,7 @@ struct _sc_graph {
 
 
 struct _sc_graph_node {
+	suint32 key;
 	spointer contents;
 	svector_t *edges;
 };
@@ -50,8 +54,7 @@ struct _sc_graph_node {
 
 struct _sc_graph_edge {
 	s_gweight_t weight;
-	s_graph_node_t headnode;
-	s_graph_node_t tailnode;
+	s_graph_node_t *tailnode;
 };
 
 
