@@ -1,7 +1,10 @@
 /*
- * $Id: list.h,v 1.6 2004/07/10 17:04:48 jklein Exp $
+ * $Id: list.h,v 1.7 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: list.h,v $
+ * Revision 1.7  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
  * Revision 1.6  2004/07/10 17:04:48  jklein
  * Added few function to sxarray_t.
  *
@@ -60,7 +63,6 @@ typedef struct _sc_linklist_node slist_node_t;
  */
 struct _sc_linklist {
 	size_t count;
-/*	sc_compf_t compare; */
 	slist_node_t *head;
 	slist_node_t *tail;
 };
@@ -76,10 +78,10 @@ struct _sc_linklist_node {
 slist_t *		s_list_alloc();
 void			s_list_free(slist_t *);
 size_t			s_list_size(slist_t *);
-void			s_list_insert_at(slist_t *, uint, const spointer);
+void			s_list_insert_at(slist_t *, suint, const spointer);
 void 			s_list_add(slist_t *, const spointer);
-spointer		s_list_get(slist_t *, uint);
-spointer		s_list_remove(slist_t *, uint);
+spointer		s_list_get(slist_t *, suint);
+spointer		s_list_remove(slist_t *, suint);
 sint32			s_list_find(slist_t *, sc_compf_t, spointer);
 sboolean		s_list_join(slist_t *, slist_t *);
 void			s_list_sort(slist_t *, sc_compf_t);
