@@ -1,7 +1,10 @@
 /**
- * $Id: scaleio.h,v 1.2 2004/06/26 06:58:13 jklein Exp $
+ * $Id: scaleio.h,v 1.3 2004/07/09 09:43:58 jklein Exp $
  * $Author: jklein $
  * $Log: scaleio.h,v $
+ * Revision 1.3  2004/07/09 09:43:58  jklein
+ * few small changes.
+ *
  * Revision 1.2  2004/06/26 06:58:13  jklein
  * small fix in each header files.
  *
@@ -22,6 +25,7 @@
 #include "scale/buffer.h"
 
 
+typedef struct _sc_file sfile_t;
 
 int		s_writef(int fd, const char *fmt, ...);
 int		s_vwritef(int fd, const char *fmt, va_list ap);
