@@ -1,7 +1,10 @@
 /*
- * $Id: vector.h,v 1.6 2004/07/10 17:04:48 jklein Exp $
+ * $Id: vector.h,v 1.7 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: vector.h,v $
+ * Revision 1.7  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
  * Revision 1.6  2004/07/10 17:04:48  jklein
  * Added few function to sxarray_t.
  *
@@ -47,10 +50,9 @@ typedef struct _vector svector_t;
 
 
 struct _vector {
+	spointer *array;
 	size_t count;
 	size_t memsize;
-	size_t nextidx;
-	spointer *array;
 };
 
 
@@ -58,16 +60,17 @@ svector_t *		s_vector_alloc(void);
 svector_t *		s_vector_allocn(size_t);
 void			s_vector_free(svector_t *);
 size_t			s_vector_size(svector_t *);
-void			s_vector_insert_at(svector_t *, uint, const spointer);
+void			s_vector_insert_at(svector_t *, suint, const spointer);
 void			s_vector_add(svector_t *, const spointer);
-spointer		s_vector_get(svector_t *, uint);
-spointer		s_vector_remove(svector_t *, uint);
+spointer		s_vector_get(svector_t *, suint);
+spointer		s_vector_remove(svector_t *, suint);
 sint32			s_vector_find(svector_t *, sc_compf_t, spointer);
 sboolean		s_vector_join(svector_t *, svector_t *);
 void			s_vector_sort(svector_t *, sc_compf_t);
 
 siterator_t *	s_vector_iterator(svector_t *);
 sxarray_t *		s_vector_xarray(void);
+sxarray_t *		s_vector_xarrayn(size_t);
 sxarray_t *		s_vector_attach_xarray(svector_t *);
 
 
