@@ -1,7 +1,10 @@
 /**
- * $Id: sc_alloc.c,v 1.3 2004/06/21 16:44:17 jklein Exp $
+ * $Id: sc_alloc.c,v 1.4 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: sc_alloc.c,v $
+ * Revision 1.4  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
  * Revision 1.3  2004/06/21 16:44:17  jklein
  * Added iterator.
  *
@@ -12,20 +15,23 @@
 #include "scale/alloc.h"
 
 
-
-#if MEMORY_DEBUG
 static size_t total_memory = 0;
 
-#  define DBG_MEMORY_ALLOC(n) {\
+
+#if MEMORY_DEBUG == 1
+#  define DBG_MEMORY_ALLOC(n) do {\
 	total_memory += n;\
 	printf("Used Memory(alloc): %d\n", total_memory);\
 }while(0)
 
-#  define DBG_MEMORY_FREE(n) {\
+#  define DBG_MEMORY_FREE(n) do {\
 	total_memory -= n;\
 	printf("Used Memory(free) : %d\n", total_memory);\
 }
-
+#elif MEMORY_DEBUG == 2
+static size_t total_memory = 0;
+#  define DBG_MEMORY_ALLOC(n) do { total_memory += n; } while(0)
+#  define DBG_MEMORY_FREE(n)  do { total_memory -= n; } while(0)
 #else
 #  define DBG_MEMORY_ALLOC(n)
 #  define DBG_MEMORY_FREE(n)
@@ -35,26 +41,36 @@ static size_t total_memory = 0;
 #define _DEF_EXIT_CODE 1
 
 
-sboolean _exit_err_handler(void);
-static merror_handler *errhandler = (merror_handler *)&_exit_err_handler;
 
 
+sboolean _exit_err_handler(void);
+static merror_handler errhandler = _exit_err_handler;
+
+
+size_t
+get_total_memory(void)
+{
+	return total_memory;
+}
+
 
 sboolean
 _exit_err_handler(void) 
 {
+	fprintf(stderr, "error: no more memory\n");
 	exit(_DEF_EXIT_CODE);
-	return true;
+	return true; /* I know this is useless.
+					But I hate to seeing worning while compile. */
 }
 
 
 void
-s_merror_handler(merror_handler *handler)
+s_merror_handler(merror_handler handler)
 {
 	if (handler)
 		errhandler = handler;
 	else
-		errhandler = (merror_handler *)&_exit_err_handler;
+		errhandler = _exit_err_handler;
 }
 
 
@@ -130,6 +146,21 @@ s_reallocn(spointer p, size_t oldsize, size_t newsize)
 }
 
 
+spointer
+s_creallocn(spointer p, size_t oldsize, size_t newsize)
+{
+	spointer newp;
+
+	newp = s_reallocn(p, oldsize, newsize);
+	if (oldsize < newsize) {
+		char *tp = (char *)newp;
+		tp += oldsize;
+		memset(tp, 0x00, newsize - oldsize);
+	}
+	
+	return newp;
+}
+
 
 void
 s_free(spointer p)
@@ -150,3 +181,11 @@ s_freen(spointer p, size_t n)
 
 	DBG_MEMORY_FREE(n);
 }
+
+
+void
+s_cfreen(spointer p, size_t n)
+{
+	memset(p, 0x00, n);
+	s_freen(p, n);
+}
