@@ -1,7 +1,13 @@
 /**
- * $Id: sc_buffer.c,v 1.5 2004/06/28 09:51:09 jklein Exp $
+ * $Id: sc_buffer.c,v 1.7 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: sc_buffer.c,v $
+ * Revision 1.7  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
+ * Revision 1.6  2004/08/04 08:55:28  jklein
+ * fixed off-by-one bug in sc_buffer.c
+ *
  * Revision 1.5  2004/06/28 09:51:09  jklein
  * interface was changed in scale/iterator.h
  *
@@ -13,7 +19,6 @@
  *
  */
 
-
 #include <stdio.h>
 #include <stdarg.h>
 
@@ -26,29 +31,33 @@
 #endif
 
 #define DEF_INITSIZE 128
-#define DEF_GROUTH_RATE 2
+#define EXTRA_MEM_GROUTH_RATIO 32
 
 
 void
 _s_buffer_grouth(sbuffer_t *sbuf, size_t newsize)
 {
-	if(newsize <= sbuf->memsize)
-		return;
-
 	sbuf->string = s_reallocn(sbuf->string, sbuf->memsize, newsize);
 	sbuf->memsize = newsize;
 }
 
 
 sbuffer_t *
-s_buffer_alloc(size_t initsize)
+s_buffer_alloc(void)
+{
+	return s_buffer_allocn(DEF_INITSIZE);
+}
+
+
+sbuffer_t *
+s_buffer_allocn(size_t initsize)
 {
 	sbuffer_t *sbuf;
 
 	if(initsize == 0)
 		initsize = DEF_INITSIZE;
 	
-	sbuf = s_malloc(sizeof(sbuffer_t));
+	sbuf = typed_malloc(sbuffer_t);
 	sbuf->memsize = initsize;
 	sbuf->string = s_calloc(sbuf->memsize, sizeof(char));
 
@@ -61,7 +70,7 @@ s_buffer_alloc_str(const char *str)
 {
 	sbuffer_t *sbuf;
 
-	sbuf = s_buffer_alloc(strlen(str) + 1);
+	sbuf = s_buffer_allocn(strlen(str) + 1);
 	strcpy(sbuf->string, str);
 	return sbuf;
 }
@@ -93,26 +102,31 @@ s_buffer_strlen(sbuffer_t *sbuf)
 
 sbuffer_t *
 s_buffer_strcat(sbuffer_t *sbuf, const char *src)
-{
-	return s_buffer_strncat(sbuf, src, strlen(src));
+{ 
+	register const size_t newlen = strlen(src) + strlen(sbuf->string);
+	
+	if (newlen + 1 > sbuf->memsize)
+		_s_buffer_grouth(sbuf, newlen + 1 + EXTRA_MEM_GROUTH_RATIO);
+
+	strcat(sbuf->string, src);
+	return sbuf;
 }
 
 
 sbuffer_t *
 s_buffer_strncat(sbuffer_t *sbuf, const char *src, size_t n)
 {
-	size_t buflen = strlen(sbuf->string);
-	size_t newlen = n + buflen + 1;
+	register const size_t newlen = n + strlen(sbuf->string);
 	
 	if (n == 0)
 		return sbuf;
 	
-	if (newlen > sbuf->memsize)
-		_s_buffer_grouth(sbuf, newlen);
+	if (newlen + 1 > sbuf->memsize)
+		_s_buffer_grouth(sbuf, newlen + 1 + EXTRA_MEM_GROUTH_RATIO);
 
 	strncat(sbuf->string, src, n);
-
 	sbuf->string[newlen] = '\0';
+
 	return sbuf;
 }
 
@@ -131,7 +145,7 @@ s_buffer_strncpy(sbuffer_t *sbuf, const char *src, size_t n)
 		return sbuf;
 
 	if (n + 1 > sbuf->memsize)
-		_s_buffer_grouth(sbuf, n + 1);
+		_s_buffer_grouth(sbuf, n + 1 + EXTRA_MEM_GROUTH_RATIO);
 
 	memset(sbuf->string, '\0', sbuf->memsize);
 	strncpy(sbuf->string, src, n);
@@ -160,13 +174,15 @@ s_buffer_vsprintf(sbuffer_t *sbuf, const char *fmt, va_list ap)
 	va_list dupap;
 	size_t newlen;
 
-	/* allocate new memoty if we need it. */
+	/* allocate new memoty if we need it.
+	   warning: Until glibc 2.0.6 they would return -1 when the output
+	   was truncated. So this code don't work on it. */
 	va_copy(dupap, ap);
 	newlen = vsnprintf(NULL, 0, fmt, dupap);
 	va_end(dupap);
 
 	if(sbuf->memsize < newlen + 1)
-		_s_buffer_grouth(sbuf, newlen + 1);
+		_s_buffer_grouth(sbuf, newlen + 1 + EXTRA_MEM_GROUTH_RATIO);
 	
 	vsprintf(sbuf->string, fmt, ap);
 	return newlen;
@@ -176,9 +192,9 @@ s_buffer_vsprintf(sbuffer_t *sbuf, const char *fmt, va_list ap)
 void
 s_buffer_chrrep(sbuffer_t *sbuf, char src, char dst)
 {
-	char *p;
+	register unsigned char *p = (unsigned char *)sbuf->string;
 
-	for (p=sbuf->string; *p != '\0'; ++p) {
+	for (; *p != '\0'; ++p) {
 		if (*p == src)
 			*p = dst;
 	}
@@ -188,10 +204,10 @@ s_buffer_chrrep(sbuffer_t *sbuf, char src, char dst)
 void
 s_buffer_strrep(sbuffer_t *sbuf, const char *src, const char *dst)
 {
-	sbuffer_t *tmpbuf = s_buffer_alloc(s_buffer_strlen(sbuf) + 16);
-	char *p, *repp;
-	size_t dstlen = strlen(dst);
-	size_t srclen = strlen(src);
+	sbuffer_t * const tmpbuf = s_buffer_allocn(s_buffer_strlen(sbuf) + 16);
+	const char *p, *repp;
+	const size_t dstlen = strlen(dst);
+	const size_t srclen = strlen(src);
 	
 	p = sbuf->string;
 	while ((repp = strstr(p, src)) != NULL) {
@@ -201,7 +217,7 @@ s_buffer_strrep(sbuffer_t *sbuf, const char *src, const char *dst)
 	}
 	s_buffer_strcat(tmpbuf, p);
 	
-	s_buffer_strcpy(sbuf, tmpbuf->string);
+	s_buffer_strncpy(sbuf, tmpbuf->string, strlen(tmpbuf->string));
 	s_buffer_free(tmpbuf);
 }
 
