@@ -1,6 +1,9 @@
-/* $Id: sc_graphviz.c,v 1.1 2004/07/10 17:04:48 jklein Exp $
+/* $Id: sc_graphviz.c,v 1.2 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: sc_graphviz.c,v $
+ * Revision 1.2  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
  * Revision 1.1  2004/07/10 17:04:48  jklein
  * Added few function to sxarray_t.
  *
@@ -17,8 +20,8 @@ s_heap_graphviz(sheap_t *heap)
 	sbuffer_t *tmpbuf;
 	int i;
 
-	buf = s_buffer_alloc(256);
-	tmpbuf = s_buffer_alloc(64);
+	buf = s_buffer_allocn(256);
+	tmpbuf = s_buffer_allocn(64);
 
 	s_buffer_strcpy(buf, "digraph G {\n");
 
@@ -54,8 +57,8 @@ s_btree_graphviz(sbtree_t *bt)
 	squeue_t *queue;
 	sbtree_node_t *node;
 
-	buf = s_buffer_alloc(256);
-	tmpbuf = s_buffer_alloc(64);
+	buf = s_buffer_allocn(256);
+	tmpbuf = s_buffer_allocn(64);
 	queue = s_queue_alloc();
 
 	s_buffer_strcpy(buf, "digraph G {\n");
