@@ -1,7 +1,10 @@
 /**
- * $Id: sc_list.c,v 1.8 2004/07/10 17:04:48 jklein Exp $
+ * $Id: sc_list.c,v 1.9 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: sc_list.c,v $
+ * Revision 1.9  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
  * Revision 1.8  2004/07/10 17:04:48  jklein
  * Added few function to sxarray_t.
  *
@@ -57,7 +60,7 @@ _sc_dump_list(const char *prompt, slist_t *list)
 
 /* returns node at 'idx'. if idx==tail, returns tail-node. */
 static slist_node_t *
-_get_node_at(slist_t *list, uint idx)
+_get_node_at(slist_t *list, suint idx)
 {
 	slist_node_t *node;
 	size_t i;
@@ -140,7 +143,7 @@ s_list_size(slist_t *list)
 
 
 void
-s_list_insert_at(slist_t *list, uint idx, const spointer contents)
+s_list_insert_at(slist_t *list, suint idx, const spointer contents)
 {
 	slist_node_t *node;
 	slist_node_t *newnode;
@@ -169,7 +172,7 @@ s_list_add(slist_t *list, const spointer contents)
 
 
 spointer
-s_list_get(slist_t *list, uint idx)
+s_list_get(slist_t *list, suint idx)
 {
 	slist_node_t *node;
 	
@@ -182,7 +185,7 @@ s_list_get(slist_t *list, uint idx)
 
 
 spointer
-s_list_remove(slist_t *list, uint idx)
+s_list_remove(slist_t *list, suint idx)
 {
 	slist_node_t *node;
 	spointer contents;
@@ -454,7 +457,7 @@ _s_list_xarr_size(sxarray_t *xarr)
 
 
 static void
-_s_list_xarr_insert_at(sxarray_t *xarr, uint idx, spointer contents)
+_s_list_xarr_insert_at(sxarray_t *xarr, suint idx, spointer contents)
 {
 	s_list_insert_at(__XARR_GET_LIST(xarr), idx, contents);
 }
@@ -507,7 +510,7 @@ _s_list_xarr_join(sxarray_t *dest, sxarray_t *src)
 {
 	slist_t *dlist = __XARR_GET_LIST(dest);
 	slist_node_t *node, *newnode;
-	uint i;
+	suint i;
 	size_t srcsize = s_xarray_size(src);
 
 	node = dlist->tail->prev;
