@@ -1,7 +1,16 @@
 /*
- * $Id: sc_vector.c,v 1.10 2004/08/02 16:38:01 jklein Exp $
+ * $Id: sc_vector.c,v 1.13 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: sc_vector.c,v $
+ * Revision 1.13  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
+ * Revision 1.12  2004/08/04 08:55:28  jklein
+ * fixed off-by-one bug in sc_buffer.c
+ *
+ * Revision 1.11  2004/08/03 05:49:50  jklein
+ * Add sxtable_t structure.
+ *
  * Revision 1.10  2004/08/02 16:38:01  jklein
  * Fixed bug in the btree.c
  *
@@ -66,7 +75,6 @@ s_vector_allocn(size_t n)
 	vect = typed_malloc(svector_t);
 	vect->count = 0;
 	vect->memsize = 0;
-	vect->nextidx = 0;
 	vect->array = NULL;
 
 	_s_vector_grouth(vect, n);
@@ -91,21 +99,19 @@ s_vector_size(svector_t *vect)
 
 
 void
-s_vector_insert_at(svector_t *vect, uint idx, const spointer contents)
+s_vector_insert_at(svector_t *vect, suint idx, const spointer contents)
 {
-	int i;
+	register int i;
 
-	if (vect->memsize == vect->nextidx)
+	if (vect->memsize == vect->count)
 		_s_vector_grouth(vect, vect->memsize + DEF_GROUTH_RATIO);
 
-	for (i=vect->count; i>idx; i--) {
+	for (i=vect->count; i>idx; --i)
 		vect->array[i] = vect->array[i-1];
-	}
 
 	vect->array[idx] = contents;
 
-	++vect->count;
-	++vect->nextidx;
+ 	++vect->count; 
 }
 
 
@@ -117,7 +123,7 @@ s_vector_add(svector_t *vect, const spointer contents)
 
 
 spointer		
-s_vector_get(svector_t *vect, uint idx) 
+s_vector_get(svector_t *vect, suint idx) 
 {
 	if (vect->count <= idx)
 		return NULL;
@@ -127,7 +133,7 @@ s_vector_get(svector_t *vect, uint idx)
 
 
 spointer		
-s_vector_remove(svector_t *vect, uint idx) 
+s_vector_remove(svector_t *vect, suint idx) 
 {
 	spointer contents;
 	sint i;
@@ -144,7 +150,6 @@ s_vector_remove(svector_t *vect, uint idx)
 	}
 	vect->array[vect->count-1] = NULL;
 	--vect->count;
-	--vect->nextidx;
 	
 	return contents;
 }
@@ -175,11 +180,9 @@ s_vector_join(svector_t *dst, svector_t *src)
 		_s_vector_grouth(dst, newsize);
 
 	for (i=0; i<src->count; i++) {
-		dst->array[dst->nextidx++] = src->array[i];
+		dst->array[dst->count++] = src->array[i];
 	}
 
-	dst->count += src->count;
-
 	return true;
 }
 
@@ -312,7 +315,7 @@ _s_vect_xarr_size(sxarray_t *xarr)
 
 
 static void
-_s_vect_xarr_insert_at(sxarray_t *xarr, uint idx, spointer contents)
+_s_vect_xarr_insert_at(sxarray_t *xarr, suint idx, spointer contents)
 {
 	s_vector_insert_at(__XARR_GET_VECT(xarr), idx, contents);
 }
@@ -365,7 +368,7 @@ _s_vect_xarr_join(sxarray_t *dest, sxarray_t *src)
 {
 	svector_t *dvect = __XARR_GET_VECT(dest);
 	size_t newsize, srcsize;
-	uint i;
+	suint i;
 
 	srcsize = s_xarray_size(src);
 	if ((newsize = dvect->count + srcsize) > dvect->memsize) {
@@ -373,10 +376,8 @@ _s_vect_xarr_join(sxarray_t *dest, sxarray_t *src)
 	}
 
 	for (i=0; i<srcsize; i++) {
-		dvect->array[dvect->nextidx++] = s_xarray_get(src, i);
+		dvect->array[dvect->count++] = s_xarray_get(src, i); 
 	}
-
-	dvect->count += srcsize;
 }
 
 
@@ -390,6 +391,16 @@ s_vector_xarray(void)
 }
 
 
+sxarray_t *
+s_vector_xarrayn(size_t n)
+{
+	svector_t *vect = s_vector_allocn(n);
+	sxarray_t *xarr = s_vector_attach_xarray(vect);
+	xarr->is_origin = true;
+	return xarr;
+}
+
+
 sxarray_t *
 s_vector_attach_xarray(svector_t *vect)
 {
