@@ -5,7 +5,7 @@
 #include "scale/scaleio.h"
 #include "scale/alloc.h"
 
-#define BUFSIZE 1024
+#define BUFSIZE 4048
 #define LARGE_BUFSIZE (BUFSIZE * 2)
 
 
@@ -21,7 +21,7 @@ _new_sfile(FILE *fp)
 	sfile_t *sf;
 
 	sf = typed_malloc(sfile_t);
-	sf->buff = s_buffer_alloc(256);
+	sf->buff = s_buffer_allocn(256);
 	sf->fp = fp;
 	return sf;
 }
@@ -110,7 +110,7 @@ s_vwritef(int fd, const char *fmt, va_list ap)
 	size_t len;
 	char *p;
 
-	sbuf = s_buffer_alloc(strlen(fmt) * 2);
+	sbuf = s_buffer_allocn(strlen(fmt) * 2);
 	len = s_buffer_vsprintf(sbuf, fmt, ap);
 	
 	p = sbuf->string;
