@@ -1,7 +1,13 @@
 /**
- * $Id: bench.c,v 1.1 2004/08/02 16:39:13 jklein Exp $
+ * $Id: bench.c,v 1.3 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: bench.c,v $
+ * Revision 1.3  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
+ * Revision 1.2  2004/08/03 05:49:50  jklein
+ * Add sxtable_t structure.
+ *
  * Revision 1.1  2004/08/02 16:39:13  jklein
  * Fixed bug in the btree.c
  *
@@ -27,6 +33,7 @@
 #include "scale/btree.h"
 #include "scale/stack.h"
 #include "scale/queue.h"
+#include "scale/buffer.h"
 
 
 /* test-data list */
@@ -53,6 +60,25 @@ bench_xarray(sxarray_t *xarr)
 }
 
 
+double 
+bench_insert_at_xarray(sxarray_t *xarr)
+{
+	clock_t stime, etime;
+	int i;
+
+	stime = clock();
+
+	for (i=0; i<tdsize; ++i)
+		s_xarray_insert_at(xarr, 0, tdlist[i]);
+	for (i=tdsize-1; i>=0; --i)
+		s_xarray_remove(xarr, i);
+
+	etime = clock();
+
+	return (etime - stime) / (double)CLOCKS_PER_SEC;
+}
+
+
 int
 bench_init(size_t tdc)
 {
@@ -86,12 +112,12 @@ finalize()
 
 
 double 
-bench_vector()
+bench_vector(size_t n)
 {
 	sxarray_t *xarr;
 	double time;
 
-	xarr = s_vector_xarray();
+	xarr = s_vector_xarrayn(n);
 	time = bench_xarray(xarr);
 	s_xarray_free(xarr);
 	return time;
@@ -203,35 +229,145 @@ bench_btree()
 }
 
 
+double
+bench_insert_at_vector()
+{
+	sxarray_t *xarr;
+	double time;
+
+	xarr = s_vector_xarray();
+	time = bench_insert_at_xarray(xarr);
+	s_xarray_free(xarr);
+	return time;
+}
+
+
+double
+bench_sbuffer_strcat()
+{
+	sbuffer_t *sbuf = s_buffer_allocn(0x10);
+	double stime, etime;
+	int i;
+
+	stime = clock();
+	for (i=0; i<tdsize; i++)
+		s_buffer_strcat(sbuf, tdlist[i]);
+	etime = clock();
+
+	s_buffer_free(sbuf);
+	return (etime - stime) / CLOCKS_PER_SEC;
+}
+
+
+double
+bench_sbuffer_chrrep()
+{
+	sbuffer_t *sbuf = s_buffer_allocn(0x10);
+	double stime, etime;
+	int i;
+
+	stime = clock();
+	for (i=0; i<tdsize; i++)
+		s_buffer_strcat(sbuf, tdlist[i]);
+	for (i=0; i<tdsize; i++)
+		s_buffer_chrrep(sbuf, (i%10)+'0', (i%10)+'1');
+	etime = clock();
+	
+	s_buffer_free(sbuf);
+	return (etime - stime) / CLOCKS_PER_SEC;
+}
+
+
+
+double
+bench_sbuffer_strrep()
+{
+	sbuffer_t *sbuf = s_buffer_allocn(0x10);
+	double stime, etime;
+	int i;
+
+	stime = clock();
+	for (i=0; i<tdsize; i++)
+		s_buffer_strcat(sbuf, tdlist[i]);
+	for (i=0; i<tdsize; i++)
+		s_buffer_strrep(sbuf, tdlist[i], "A");
+	etime = clock();	
+
+	s_buffer_free(sbuf);
+	return (etime - stime) / CLOCKS_PER_SEC;
+}
+
+
+void
+bench_sbuffer()
+{
+	int benchlist[] = {
+		5000, 10000, -1
+	};
+	int i = 0, benchsize;
+
+	while ( (benchsize = benchlist[i++]) != -1) {
+		bench_init(benchsize);
+		printf("[ count = %d ]\n", benchsize);
+		printf("  strcat : %.3f\n", bench_sbuffer_strcat());
+		printf("  chrrep : %.3f\n", bench_sbuffer_chrrep());
+		printf("  strrep : %.3f\n", bench_sbuffer_strrep());
+		printf("\n");
+		finalize();
+	}
+}
+
+
+void
+bench_arrays(void)
+{
+	int benchlist[] = {
+		100000, 500000, 1000000, -1
+	};
+	int i = 0, benchsize;
+
+	printf("Array Benchmark\n");
+	
+	while ( (benchsize = benchlist[i++]) != -1) {
+		bench_init(benchsize);
+		printf("[ count = %d ]\n", benchsize);
+		printf("  Vector        : %.4f\n", bench_vector(64));
+//		printf("  Vector(ins at): %.4f\n", bench_insert_at_vector());
+		printf("  Vector(large) : %.4f\n", bench_vector(tdsize));
+		printf("  List          : %.4f\n", bench_list());
+		printf("  Heap          : %.4f\n", bench_heap());
+		printf("  Stack         : %.4f\n", bench_stack());
+		finalize();
+	}
+}
+
+
+void
+bench_tables(void)
+{
+	int benchlist[] = {
+		100000, 500000, -1
+	};
+	int i = 0, benchsize;
+
+	printf("Table Benchmark\n");
+	while ( (benchsize = benchlist[i++]) != -1) {
+		bench_init(benchsize);
+		printf("[ count = %d ]\n", benchsize);
+		printf("  Hash          : %.4f\n", bench_hash(tdsize/2));
+		printf("  Hash(large)   : %.4f\n", bench_hash(tdsize*2));
+		printf("  BTree         : %.4f\n", bench_btree());
+		finalize();
+	}
+}
+
+
 int
 main(int argc, char *argv[])
 {
-	int benchlist[] = {
-		1000, 3000, 5000, 10000, 50000, 100000, 
-		123, 1234, 12345, 123456, 10, 12, 19,
-		54321, 4321, 321, 21, 1, 99, 999, 9999, 99999,
-		8989, 9898, 7878, 8787, 6767, 5643, 1357, 2468,
-		123456, 200000,
-		-1
-	};
-	int i;
-
-	i = 0;
-	while (benchlist[i] != -1) {
-		bench_init(benchlist[i]);
-		printf("Bench-mark test(count = %d)\n", benchlist[i]);
-
-		printf("  Vector: %.3f\n", bench_vector());
-		printf("  List  : %.3f\n", bench_list());
-		printf("  Heap  : %.3f\n", bench_heap());
-		printf("  Stack : %.3f\n", bench_stack());
-		printf("  Hash        : %.4f\n", bench_hash(1024));
-		printf("  Hash(large) : %.4f\n", bench_hash(tdsize*2));
-		printf("  BTree       : %.4f\n", bench_btree());
-		printf("\n");
-		finalize();
-		i++;
-	}
+	bench_arrays();
+	bench_tables();
+	bench_sbuffer();
 
 	return EXIT_SUCCESS;
 }
