@@ -1,7 +1,13 @@
 /**
- * $Id: tester.c,v 1.12 2004/08/02 16:39:13 jklein Exp $
+ * $Id: tester.c,v 1.14 2004/08/05 13:54:30 jklein Exp $
  * $Author: jklein $
  * $Log: tester.c,v $
+ * Revision 1.14  2004/08/05 13:54:30  jklein
+ * Fixed so that Scale can be compiled on Mac OSX(10.3 or higher).
+ *
+ * Revision 1.13  2004/08/03 05:49:50  jklein
+ * Add sxtable_t structure.
+ *
  * Revision 1.12  2004/08/02 16:39:13  jklein
  * Fixed bug in the btree.c
  *
@@ -276,7 +282,7 @@ sxtable_test(sxtable_t *xt)
 	{/* test iterator */
 		siterator_t *keys;
 		char *key;
-		int has_read = 1 | 2 | 4 | 8;
+		int has_read = 0;
 
 		s_xtable_put(xt, "1", "a");
 		s_xtable_put(xt, "2", "b");
@@ -289,26 +295,26 @@ sxtable_test(sxtable_t *xt)
 			if (strcmp(key, "1") == 0) {
 				if (has_read & 1)
 					fprintf(stderr, "ERROR(%d)\n", __LINE__);
-				has_read = has_read & ~1;
+				has_read = has_read | 1;
 			}
 			else if (strcmp(key, "2") == 0) {
 				if (has_read & 2)
 					fprintf(stderr, "ERROR(%d)\n", __LINE__);
-				has_read = has_read & ~2;
+				has_read = has_read | 2;
 			}
 			else if (strcmp(key, "4") == 0) {
 				if (has_read & 4)
 					fprintf(stderr, "ERROR(%d)\n", __LINE__);
-				has_read = has_read & ~4;
+				has_read = has_read | 4;
 			}
 			else if (strcmp(key, "8") == 0) {
 				if (has_read & 8)
 					fprintf(stderr, "ERROR(%d)\n", __LINE__);
-				has_read = has_read & ~8;
+				has_read = has_read | 8;
 			}
 		}
 
-		if (has_read != 0) {
+		if (has_read != (1|2|4|8)) {
 			fprintf(stderr, "not read all\n");
 			return 0;
 		}
@@ -530,7 +536,7 @@ test_buffer(void)
 
 	FUNC_START();
 
-	sbuf = s_buffer_alloc(1024);
+	sbuf = s_buffer_allocn(1024);
 
 	assert(s_buffer_strlen(sbuf) == 0);
 
@@ -712,9 +718,9 @@ test_heap()
 
 	assert(s_heap_size(heap) == 6);
 
-	sbuffer_t *gbuf = s_heap_graphviz(heap);
-	printf("%s\n", gbuf->string);
-	s_buffer_free(gbuf);
+/* 	sbuffer_t *gbuf = s_heap_graphviz(heap); */
+/* 	printf("%s\n", gbuf->string); */
+/* 	s_buffer_free(gbuf); */
 
 	assert(strcmp(s_heap_pop(heap), "F") == 0);
 	assert(strcmp(s_heap_pop(heap), "E") == 0);
